@@ -12,7 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from superlinked.framework.common.exception import InitializationException
+from superlinked.framework.common.exception import InvalidStateException
 from superlinked.framework.common.schema.event_schema_object import SchemaReference
 from superlinked.framework.common.schema.id_schema_object import IdSchemaObject
 
@@ -20,7 +20,7 @@ from superlinked.framework.common.schema.id_schema_object import IdSchemaObject
 class SchemaObjectReference:
     def __init__(self, schema: IdSchemaObject, reference_field: SchemaReference) -> None:
         if not isinstance(schema, reference_field._referenced_schema):
-            raise InitializationException(f"{self.__class__.__name__}'s schema is not the referenced schema.")
+            raise InvalidStateException(f"{self.__class__.__name__}'s schema is not the referenced schema.")
         self.schema = schema
         self.reference_field = reference_field
 
