@@ -15,14 +15,9 @@
 
 from typing_extensions import override
 
-from superlinked.framework.common.dag.constant_node import ConstantNode
 from superlinked.framework.common.dag.embedding_node import EmbeddingNode
 from superlinked.framework.common.dag.number_embedding_node import NumberEmbeddingNode
 from superlinked.framework.common.dag.schema_field_node import SchemaFieldNode
-from superlinked.framework.common.exception import (
-    InvalidInputException,
-    NotImplementedException,
-)
 from superlinked.framework.common.schema.schema_object import Number, SchemaObject
 from superlinked.framework.common.space.config.aggregation.aggregation_config import (
     AggregationConfig,
@@ -42,7 +37,6 @@ from superlinked.framework.common.space.config.normalization.normalization_confi
 from superlinked.framework.common.space.config.transformation_config import (
     TransformationConfig,
 )
-from superlinked.framework.common.util.lazy_property import lazy_property
 from superlinked.framework.dsl.space.has_space_field_set import HasSpaceFieldSet
 from superlinked.framework.dsl.space.input_aggregation_mode import InputAggregationMode
 from superlinked.framework.dsl.space.space import Space
@@ -215,26 +209,4 @@ class NumberSpace(Space[float, float], HasSpaceFieldSet):
 
     @override
     def _create_default_node(self, schema: SchemaObject) -> EmbeddingNode[float, float]:
-        constant_node = ConstantNode(value=self._default_constant_node_input, schema=schema)
-        default_node = NumberEmbeddingNode(
-            parent=constant_node,
-            transformation_config=self._transformation_config,
-            fields_for_identification=self.number.fields,
-        )
-        return default_node
-
-    @lazy_property
-    def _default_constant_node_input(self) -> float:
-        match self._embedding_config.mode:
-            case Mode.MAXIMUM:
-                default_constant_node_input = self._embedding_config.max_value
-            case Mode.MINIMUM:
-                default_constant_node_input = self._embedding_config.min_value
-            case Mode.SIMILAR:
-                raise InvalidInputException(
-                    "Number Space with SIMILAR Mode do not have a default value, a .similar "
-                    "clause is needed in the query."
-                )
-            case _:
-                raise NotImplementedException(f"Unknown mode: {self._embedding_config.mode}")
-        return default_constant_node_input
+        return NumberEmbeddingNode(None, self._transformation_config, self.number.fields, schema)
