@@ -15,16 +15,11 @@
 from beartype.typing import Sequence, cast
 
 from superlinked.framework.common.dag.context import ExecutionContext
-from superlinked.framework.common.dag.exception import (
-    LeafNodeCountException,
-    LeafNodeTypeException,
-    MultipleRootSchemaException,
-)
 from superlinked.framework.common.dag.node import Node
 from superlinked.framework.common.dag.schema_field_node import SchemaFieldNode
 from superlinked.framework.common.data_types import Vector
+from superlinked.framework.common.exception import InvalidStateException
 from superlinked.framework.common.parser.parsed_schema import ParsedSchema
-from superlinked.framework.common.schema.exception import SchemaMismatchException
 from superlinked.framework.common.schema.schema_object import SchemaObject
 from superlinked.framework.online.dag.evaluation_result import EvaluationResult
 from superlinked.framework.online.dag.online_index_node import OnlineIndexNode
@@ -71,21 +66,21 @@ class OnlineSchemaDag:
         class_name = type(self).__name__
         leaf_nodes = [node for node in nodes if len(node.children) == 0]
         if len(leaf_nodes) != 1:
-            raise LeafNodeCountException(f"{class_name} must have exactly one leaf Node.")
+            raise InvalidStateException(f"{class_name} must have exactly one leaf Node.")
         if not isinstance(leaf_nodes[0], OnlineIndexNode):
-            raise LeafNodeTypeException(f"{class_name} must have a OnlineIndexNode leaf Node.")
+            raise InvalidStateException(f"{class_name} must have a OnlineIndexNode leaf Node.")
         root_node_schemas = set(
             cast(SchemaFieldNode, node.node).schema_field.schema_obj
             for node in nodes
             if isinstance(node, OnlineSchemaFieldNode)
         )
         if len(root_node_schemas) != 1:
-            raise MultipleRootSchemaException(f"{class_name}'s nodes must have the same root schema.")
+            raise InvalidStateException(f"{class_name}'s nodes must have the same root schema.")
         if schema not in root_node_schemas:
-            raise SchemaMismatchException(
+            raise InvalidStateException(
                 (
-                    f"{class_name} was instantiated with a schema object different from the nodes' root schema ",
-                    f"object: {schema.__class__.__name__} <> {list(root_node_schemas)[0]._base_class_name}.",
+                    f"{class_name} was instantiated with a schema object different from the nodes' root schema "
+                    f"object: {type(schema).__name__} <> {list(root_node_schemas)[0]._base_class_name}."
                 )
             )
 
