@@ -17,10 +17,15 @@ from dataclasses import dataclass
 from beartype.typing import Generic
 
 from superlinked.framework.common.dag.node import NodeDataT
-from superlinked.framework.common.interface.weighted import Weighted
+
+
+@dataclass(frozen=True)
+class QueryNodeInputValue(Generic[NodeDataT]):
+    item: NodeDataT
+    weight: float | dict[str, float]
 
 
 @dataclass(frozen=True)
 class QueryNodeInput(Generic[NodeDataT]):
-    value: Weighted[NodeDataT]
+    value: QueryNodeInputValue[NodeDataT]
     to_invert: bool
