@@ -14,7 +14,7 @@
 
 from beartype.typing import Sequence
 from redis.commands.search.field import Field as RedisField
-from redis.commands.search.field import NumericField, TagField, TextField
+from redis.commands.search.field import NumericField, TagField
 from redis.commands.search.field import VectorField as RedisVectorField
 
 from superlinked.framework.common.calculation.distance_metric import DistanceMetric
@@ -27,8 +27,10 @@ from superlinked.framework.common.storage.search_index.index_field_descriptor im
 RedisFieldTypeByFieldDataType: dict[FieldDataType, type[RedisField]] = {
     FieldDataType.DOUBLE: NumericField,
     FieldDataType.INT: NumericField,
-    FieldDataType.STRING: TextField,
+    FieldDataType.STRING: TagField,
+    FieldDataType.METADATA_STRING: TagField,
     FieldDataType.STRING_LIST: TagField,
+    FieldDataType.BOOLEAN: TagField,
 }
 
 DistanceMetricMap = {
@@ -41,14 +43,13 @@ DistanceMetricMap = {
 class RedisFieldDescriptorCompiler:
     @staticmethod
     def compile_descriptors(
-        vector_field_descriptor: VectorIndexFieldDescriptor,
         field_descriptors: Sequence[IndexFieldDescriptor],
     ) -> Sequence[RedisField]:
         return [
             field
             for field in [
                 RedisFieldDescriptorCompiler._compile_descriptor(field_descriptor)
-                for field_descriptor in ([vector_field_descriptor] + list(field_descriptors))
+                for field_descriptor in field_descriptors
             ]
             if field is not None
         ]
@@ -60,16 +61,19 @@ class RedisFieldDescriptorCompiler:
         if field_descriptor.field_data_type == FieldDataType.VECTOR:
             if isinstance(field_descriptor, VectorIndexFieldDescriptor):
                 algorithm = field_descriptor.search_algorithm.value
-                coordinate_type = field_descriptor.coordinate_type.value
+                vector_precision = field_descriptor.vector_precision.value
                 return RedisVectorField(
                     field_descriptor.field_name,
                     algorithm,
                     {
-                        "TYPE": coordinate_type,
+                        "TYPE": vector_precision,
                         "DIM": field_descriptor.field_size,
                         "DISTANCE_METRIC": DistanceMetricMap[field_descriptor.distance_metric],
                     },
                 )
         elif redis_field_cls := RedisFieldTypeByFieldDataType.get(field_descriptor.field_data_type):
-            return redis_field_cls(field_descriptor.field_name, sortable=True)
+            field = redis_field_cls(field_descriptor.field_name, sortable=True)
+            if isinstance(field, TagField):
+                field.args_suffix.append("UNF")
+            return field
         return None
